#!/usr/bin/env python
# -*- coding: utf-8 -*-

__title__ = 'kyra'
__version__ = '0.4'
__author__ = 'Martin Simon <me@martinsimon.me>'
__repo__ = 'https://github.com/mrsmn/kyra'
__license__ = 'Apache v2.0 License'

from .core import Logger
